==> mod_fast_bbs-1.0.2.tgz: mod_fast_bbs-1.0.2/include/BBSThreadIO.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: BBSThreadIO.h 1848 2006-10-21 14:14:40Z svn $
 *****************************************************************************/

#ifndef BBS_THREAD_IO_H
#define BBS_THREAD_IO_H

#include "Environment.h"

#include "apr_pools.h"

#include "Uncopyable.h"

/**
 * @brief BBS のスレッドの I/O を行うクラス．
 */
class BBSThreadIO: public Uncopyable
{
public:
    /**
     * コンストラクタです．
     *
     * @param[in] pool プール
     * @param[in] dir_path スレッドが保存されているディレクトリ
     */
    BBSThreadIO(apr_pool_t *pool, const char *dir_path);
    virtual ~BBSThreadIO();

    static const char *get_file_path(apr_pool_t *pool, const char *dir_path,
                                     apr_size_t thread_id,
                                     const char *file_name);
    static const char *get_sub_dir_path(apr_pool_t *pool, const char *dir_path,
                                        apr_size_t thread_id);
    static void prepare_subdir(apr_pool_t *pool, const char *dir_path,
                               apr_size_t thread_id);

protected:
    const char *get_sub_dir_path(apr_pool_t *pool, apr_size_t thread_id) const;
    const char *get_file_path(apr_pool_t *pool, apr_size_t thread_id) const;
    void prepare_subdir(apr_pool_t *pool, apr_size_t thread_id) const;

    /** プール */
    apr_pool_t *pool_;
    /** スレッドが保存されているディレクトリ */
    const char *dir_path_;
};

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:

==> mod_fast_bbs-1.0.5.tgz: mod_fast_bbs-1.0.5/include/BBSThreadIO.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: BBSThreadIO.h 2079 2006-11-25 14:00:01Z svn $
 *****************************************************************************/

#ifndef BBS_THREAD_IO_H
#define BBS_THREAD_IO_H

#include "Environment.h"

#include "apr_pools.h"

#include "Uncopyable.h"

/**
 * @brief 掲示板のスレッドの I/O を行うクラス．
 */
class BBSThreadIO: public Uncopyable
{
public:
    /**
     * コンストラクタです．
     *
     * @param[in] pool プール
     * @param[in] dir_path スレッドが保存されているディレクトリ
     */
    BBSThreadIO(apr_pool_t *pool, const char *dir_path);
    virtual ~BBSThreadIO();

    static const char *get_file_path(apr_pool_t *pool, const char *dir_path,
                                     apr_size_t thread_id,
                                     const char *file_name);
    static const char *get_sub_dir_path(apr_pool_t *pool, const char *dir_path,
                                        apr_size_t thread_id);
    static void prepare_subdir(apr_pool_t *pool, const char *dir_path,
                               apr_size_t thread_id);

protected:
    const char *get_file_path(apr_pool_t *pool, apr_size_t thread_id) const;
    void prepare_subdir(apr_pool_t *pool, apr_size_t thread_id) const;

    /** プール */
    apr_pool_t *pool_;

private:
    /** スレッドが保存されているディレクトリ */
    const char *dir_path_;
};

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
